@@ -2,26 +2,20 @@ package Class::Usul;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.58.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.59.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
-use Class::Usul::Constants  qw( EXCEPTION_CLASS FALSE TRUE );
-use Class::Usul::Functions  qw( data_dumper merge_attributes
-                                untaint_identifier );
+use Class::Usul::Constants  qw( FALSE TRUE );
+use Class::Usul::Functions  qw( data_dumper merge_attributes );
 use Class::Usul::Types      qw( Bool ConfigType EncodingType HashRef
                                 L10NType LoadableClass LockType LogType );
 use Moo;
 
 # Attribute constructors
 my $_build_lock = sub {
-   my $self   = shift;
-   my $config = $self->config;
-   my $attr   = { %{ $config->lock_attributes } };
+   my $self = shift; my $attr = { %{ $self->config->lock_attributes } };
 
-   merge_attributes $attr, $self,   {}, [ 'debug', 'log' ];
-   merge_attributes $attr, $config, { 'exception_class' => EXCEPTION_CLASS },
-                                    [ 'exception_class', 'tempdir' ];
-
-   $attr->{type} = untaint_identifier $attr->{type};
+   merge_attributes $attr, $self,         {}, [ 'debug', 'log' ];
+   merge_attributes $attr, $self->config, {}, [ 'tempdir' ];
 
    return $self->lock_class->new( $attr );
 };
@@ -44,7 +38,7 @@ has 'encoding'     => is => 'lazy', isa => EncodingType,
 
 has 'l10n'         => is => 'lazy', isa => L10NType,
    builder         => sub { $_[ 0 ]->l10n_class->new( builder => $_[ 0 ] ) },
-   handles         => [ 'localize' ];
+   handles         => [ 'loc', 'localize' ];
 
 has 'l10n_class'   => is => 'lazy', isa => LoadableClass, coerce => TRUE,
    default         => 'Class::Usul::L10N';
@@ -67,14 +61,15 @@ sub dumper { # Damm handy for development
 
 1;
 
-# <a href="https://travis-ci.org/pjfl/p5-class-usul"><img src="https://travis-ci.org/pjfl/p5-class-usul.svg?branch=master" alt="Travis CI Badge"></a>
-
 __END__
 
 =pod
 
+=encoding utf8
+
 =begin html
 
+<a href="https://travis-ci.org/pjfl/p5-class-usul"><img src="https://travis-ci.org/pjfl/p5-class-usul.svg?branch=master" alt="Travis CI Badge"></a>
 <a href="http://badge.fury.io/pl/Class-Usul"><img src="https://badge.fury.io/pl/Class-Usul.svg" alt="CPAN Badge"></a>
 <a href="http://cpants.cpanauthors.org/dist/Class-Usul"><img src="http://cpants.cpanauthors.org/dist/Class-Usul.png" alt="Kwalitee Badge"></a>
 
@@ -86,7 +81,7 @@ Class::Usul - A base class providing config, locking, logging, and l10n
 
 =head1 Version
 
-Describes Class::Usul version v0.58.$Rev: 1 $
+Describes Class::Usul version v0.59.$Rev: 1 $
 
 =head1 Synopsis
 
@@ -216,9 +211,9 @@ There are no known incompatibilities in this module
 
 =head1 Bugs and Limitations
 
-There are no known bugs in this module.
-Please report problems to the address below.
-Patches are welcome
+There are no known bugs in this module. Please report problems to
+http://rt.cpan.org/NoAuth/Bugs.html?Dist=Class-Usul. Patches are
+welcome
 
 =head1 Author
 
